import org.uddi4j.*;
import org.uddi4j.response.*;
import org.uddi4j.client.*;
import org.uddi4j.datatype.*;
import org.uddi4j.datatype.business.*;
import org.uddi4j.datatype.service.*;
import org.uddi4j.datatype.tmodel.*;
import org.uddi4j.util.*;
import org.uddi4j.transport.*;

import java.util.*;
import java.net.*;

/**
 * This sample retrieves a list of businessEntity entries
 * based on a given set of FindQualifiers. It will return
 * all entries whose names start with an "I".
 * 
 * @author Andre Tost
 */
public class UDDI4JFindSample {

  public static final String inquiryURL = 
    "http://www-3.ibm.com/services/uddi/v2beta/inquiryapi";

  protected UDDIProxy proxy = null;
  protected BusinessEntity businessEntity = null;

  public static void main(String args[]) throws Exception {
    UDDI4JFindSample sample = new UDDI4JFindSample();
    try {
      sample.init();
      sample.list("%", sample.proxy);
    } catch (MalformedURLException urle) {
      System.out.println("Bad URL Exception! " + urle);
    } catch (Exception e) {
      System.out.println("Exception : " + e);
      e.printStackTrace();
    }
  }

  /**
   * creates a new proxy instance for the specified access URLs
   */
  protected void init() 
          throws MalformedURLException, UDDIException, TransportException {
    proxy = new UDDIProxy(new URL(inquiryURL), null);
  }

  /**
   * retrieves a list of businessEntity elements based on a FindQualifier entry
   */
  public BusinessList list(String businessName, UDDIProxy proxy) 
          throws UDDIException, TransportException {

    Vector v = new Vector();
    v.addElement(new FindQualifier(FindQualifier.caseSensitiveMatch));
    v.addElement(new FindQualifier(FindQualifier.sortByNameAsc));

    FindQualifiers findQualifiers = new FindQualifiers();
    findQualifiers.setFindQualifierVector(v);

    Vector names = new Vector();
    names.addElement(new Name(businessName));
    BusinessList list = proxy.find_business(names, null, null, null, null, 
                                            findQualifiers, 0);
    return list;
  }
}