import java.net.*;
import java.util.*;

import org.uddi4j.*;
import org.uddi4j.client.*;
import org.uddi4j.response.*;
import org.uddi4j.datatype.business.*;
import org.uddi4j.datatype.*;
import org.uddi4j.util.*;
import org.uddi4j.transport.*;

/**
 * This sample createa a new businessEntity entry with a
 * categoryBag, which is then stored in the registry.
 * 
 * @author Andre Tost
 */
public class UDDI4JPublishSample {

  public static final String inquiryURL = 
    "http://www.ibm.com/services/uddi/v2beta/inquiryapi";
  public static final String publishURL = 
    "https://www-3.ibm.com/services/uddi/v2beta/protect/publishapi";
  public static final String userid = "[userid]";
  public static final String password = "[password]";

  protected UDDIProxy proxy = null;
  protected String authInfo = null;

  public static void main(String args[]) throws Exception {

    System.setProperty("java.protocol.handler.pkgs", 
                       "com.sun.net.ssl.internal.www.protocol");
    java.security.Security
      .addProvider(new com.sun.net.ssl.internal.ssl.Provider());

    UDDI4JPublishSample sample = new UDDI4JPublishSample();
    try {
      sample.init();
      sample.publishBusiness();
    } catch (Exception e) {
      System.out.println("Exception : " + e);
    }
  }

  // creates a new proxy instance for the specified access URLs
  protected void init() 
          throws MalformedURLException, TransportException, UDDIException {
    proxy = new UDDIProxy(new URL(inquiryURL), new URL(publishURL));


    // Get an authentication token
    // Pass in userid and password registered at the UDDI site
    authInfo = proxy.get_authToken(userid, password).getAuthInfoString();
  } 

  // creates a new businessEntity entry in the registry , including a categoryBag
  protected void publishBusiness() 
          throws UDDIException, TransportException {

    // create a new keyedReference for the categoryBag. The name and
    // value come from the NAICS standard. The tModelKey points to the
    // NAICS taxonomy tModel. This is a hardcoded value.
    KeyedReference kr = 
      new KeyedReference("Administrative Management and General Management Consulting Services", 
                         "541611");
    kr.setTModelKey("UUID:C0B9FE13-179F-413D-8A5B-5004DB8E5BB2");

    Vector krVector = new Vector();
    krVector.addElement(kr);

    // the categoryBag contains a vector of keyedReference objects
    CategoryBag cb = new CategoryBag();
    cb.setKeyedReferenceVector(krVector);

    // create an Address object - each object contains a vector of
    // addressStrings that describe the address
    org.uddi4j.datatype.business.Address address = 
      new org.uddi4j.datatype.business.Address();
    Vector addressStrings = new Vector();
    addressStrings.add("1234 1st Ave SW");
    addressStrings.add("Rochester, MN 55902");
    addressStrings.add("USA");
    address.setAddressLineStrings(addressStrings);

    // a Contact contains a name, a vector of Address objects and a
    // vector with email addresses
    Contact contact = new Contact();
    contact.setPersonName("Joe Smith");

    Vector addresses = new Vector();
    addresses.add(address);
    contact.setAddressVector(addresses);

    Vector emails = new Vector();
    emails.add(new Email("joes@officeservices.com"));
    contact.setEmailVector(emails);

    // several Contact objects are contained in a Contacts object, which
    // can be added to the businessEntity entry
    Contacts contacts = new Contacts();
    Vector contactVector = new Vector();
    contactVector.add(contact);
    contacts.setContactVector(contactVector);

    BusinessEntity be = new BusinessEntity();
    be.setDefaultNameString("Bill's Office Services", "en");
    be.setDefaultDescriptionString("A business offering services around the office");
    be.setBusinessKey("");
    be.setContacts(contacts);

    be.setCategoryBag(cb);

    // the save_business function expectds a vector of businessEntity
    // objects, so we'll create one here with one element in it - then we
    // can save the entry, which will cause it to be created in the
    // registry
    Vector beVector = new Vector();
    beVector.addElement(be);

    proxy.save_business(authInfo, beVector);
    System.out.println("Business saved.");
  }
}