package com.wroxcuisine.xml;

import java.util.*;
import java.io.*;

// WroxCuisine EJB Packages
import com.wroxcuisine.ejb.*;

// JDOM Packages
import org.jdom.*;
import org.jdom.input.*;
import org.jdom.output.*;

import com.wroxcuisine.helpers.Recipe;
import com.wroxcuisine.helpers.Country;

public class XMLGenerator {
  public static String getAllRecipesXML(Collection recipes, 
                                        boolean xmlHeader) throws Exception {

    Element rootElement = new Element("RECIPELIST");
    Iterator iterator = recipes.iterator();
    while (iterator.hasNext()) {
      Recipe recipe = (Recipe) iterator.next();
      Document doc = getRecipeXML(recipe);
      rootElement.addContent((Element) doc.getRootElement().clone());
    } 

    XMLOutputter output = new XMLOutputter("  ", true);
    if (xmlHeader) {
      Document doc = new Document(rootElement);
      return output.outputString(doc);
    } else {
      return output.outputString(rootElement);
    }
  }

  public static Document getRecipeXML(Recipe recipe) throws Exception {
    try {

      // ROOT ELEMENT
      Element rootElement = new Element("RECIPE");

      rootElement.setAttribute("RECIPEID", 
                               String.valueOf(recipe.getRecipeId()));
      rootElement.setAttribute("COUNTRYID", 
                               String.valueOf(recipe.getCountryId()));

      // RECIPENAME
      Element recipeName = new Element("RECIPENAME");
      recipeName.setText(recipe.getRecipeName());

      // RECIPEDESC
      Element recipeDesc = new Element("RECIPEDESC");
      recipeDesc.setText(recipe.getRecipeDesc());

      // RECIPESTEPS
      Element recipeSteps = new Element("RECIPESTEPS");

      // String Tokenize over here
      String RecipeSteps = recipe.getRecipeSteps();
      StringTokenizer steps = new StringTokenizer(RecipeSteps, ";");
      int stepnum = 1;
      while (steps.hasMoreElements()) {
        Element recipeStep = new Element("STEP");
        recipeStep.setAttribute("STEPNUM", String.valueOf(stepnum));
        recipeStep.setText((String) steps.nextElement());
        recipeSteps.addContent(recipeStep);
        stepnum++;
      }

      // INGREDIENTS
      Element recipeIngredients = new Element("RECIPEINGREDIENTS");

      // String Tokenize over here
      String strIngredients = recipe.getRecipeIngredients();
      StringTokenizer ingredients = new StringTokenizer(strIngredients, 
              ";");
      int ingredientnum = 1;
      while (ingredients.hasMoreElements()) {
        Element recipeIngredient = new Element("INGREDIENT");
        recipeIngredient.setAttribute("INGREDIENTNUM", 
                                      String.valueOf(ingredientnum));
        recipeIngredient.setText((String) ingredients.nextElement());
        recipeIngredients.addContent(recipeIngredient);
        ingredientnum++;
      }


      // Create the Structure
      rootElement.addContent(recipeName);
      rootElement.addContent(recipeDesc);
      rootElement.addContent(recipeIngredients);
      rootElement.addContent(recipeSteps);

      XMLOutputter output = new XMLOutputter("  ", true);
      Document doc = new Document(rootElement);
      return doc;
    } catch (Exception e) {
      throw new Exception(e.getMessage());
    }
  }

  public static String getRecipeXML(Recipe recipe, 
                                    boolean xmlHeader) throws Exception {

    try {

      // ROOT ELEMENT
      Element rootElement = new Element("RECIPE");

      rootElement.setAttribute("RECIPEID", 
                               String.valueOf(recipe.getRecipeId()));
      rootElement.setAttribute("COUNTRYID", 
                               String.valueOf(recipe.getCountryId()));

      // RECIPENAME
      Element recipeName = new Element("RECIPENAME");
      recipeName.setText(recipe.getRecipeName());

      // RECIPEDESC
      Element recipeDesc = new Element("RECIPEDESC");
      recipeDesc.setText(recipe.getRecipeDesc());

      // RECIPESTEPS
      Element recipeSteps = new Element("RECIPESTEPS");

      // String Tokenize over here
      String RecipeSteps = recipe.getRecipeSteps();
      StringTokenizer steps = new StringTokenizer(RecipeSteps, ";");
      int stepnum = 1;
      while (steps.hasMoreElements()) {
        Element recipeStep = new Element("STEP");
        recipeStep.setAttribute("STEPNUM", String.valueOf(stepnum));
        recipeStep.setText((String) steps.nextElement());
        recipeSteps.addContent(recipeStep);
        stepnum++;
      } 

      // INGREDIENTS
      Element recipeIngredients = new Element("RECIPEINGREDIENTS");

      // String Tokenize over here
      String strIngredients = recipe.getRecipeIngredients();
      StringTokenizer ingredients = new StringTokenizer(strIngredients, 
              ";");
      int ingredientnum = 1;
      while (ingredients.hasMoreElements()) {
        Element recipeIngredient = new Element("INGREDIENT");
        recipeIngredient.setAttribute("INGREDIENTNUM", 
                                      String.valueOf(ingredientnum));
        recipeIngredient.setText((String) ingredients.nextElement());
        recipeIngredients.addContent(recipeIngredient);
        ingredientnum++;
      } 

      // Create the Structure
      rootElement.addContent(recipeName);
      rootElement.addContent(recipeDesc);
      rootElement.addContent(recipeIngredients);
      rootElement.addContent(recipeSteps);

      XMLOutputter output = new XMLOutputter("  ", true);
      if (xmlHeader) {
        Document doc = new Document(rootElement);
        return output.outputString(doc);
      } else {
        return output.outputString(rootElement);
      }
    } catch (Exception e) {
      throw new Exception(e.getMessage());
    }
  }

  public static String getAllCountriesXML(Collection countries, 
                                          boolean xmlHeader) throws Exception {

    try {
      SAXBuilder builder = new SAXBuilder();

      // ROOT ELEMENT
      Element rootElement = new Element("COUNTRYLIST");

      Iterator iterator = countries.iterator();
      while (iterator.hasNext()) {
        Country country = (Country) iterator.next();
        Element countryElement = new Element("COUNTRY");
        countryElement
          .addContent(new Element("COUNTRYID")
            .setText(String.valueOf(country.getCountryId())));
        countryElement
          .addContent(new Element("COUNTRYNAME")
            .setText(country.getCountryName()));
        countryElement
          .addContent(new Element("COUNTRYDESC")
            .setText(country.getCountryDesc()));
        rootElement.addContent(countryElement);
      }

      XMLOutputter output = new XMLOutputter("  ", true);
      if (xmlHeader) {
        Document doc = new Document(rootElement);
        return output.outputString(doc);
      } else {
        return output.outputString(rootElement);
      }
    } catch (Exception e) {
      throw new Exception(e.getMessage());
    }
  }
}