package com.wrox.jobresume.jaxrpc;

import javax.servlet.Servlet;
import java.util.Hashtable;
import com.wrox.jobresume.common.Resume;

public class JobResumeRepositoryProviderImpl
             implements Servlet, JobResumeRepositoryProvider {

  private Hashtable resumeList;
  private int resumeUID;

  /* Initializes the servlet. */
  public void init(ServletConfig config) throws ServletException {

    //Create an Hashtable to hold the resumes
    resumeList = new Hashtable();

    // Initiate the resumeCounter to 1000
    resumeUID = 1000;

    // Create a default resume
    Resume resume = createDefaultResume();
    submit(resume);

  }

  /* Destroys the servlet. */
  public void destroy() {

    // Releases Memory
    resultList=null;
  }

  /* Returns a short description of the service definition class. */
  public String getServletInfo() {
    return "Job Resume Repository Service Definition Class";
  }

  /* Stores a resume in the Hashtable */
  public int submit(Resume resume) throws java.rmi.RemoteException,
                                          IllegalArgumentException {

    if (resume == null) {
     throw new IllegalArgumentException("The resume argument must not be null");
    }
    try {
      // Generate a uid for the resume
      String uid = new Integer(resumeUID).toString();
      resumeUID+=1;

      // Store the uid with the resume object
      resume.setUid(uid);

      // Store the resume object in the hashtable
      resumeList.put(resume.getUid(),resume);
      return uid ; // return the generated uid
    } catch (NullPointerException e) {
      // completed unsuccesfully - the resume was not stored 
      return null;
    }
  }

  /* Retrives a resume from the Hashtable */
  public Resume retrieve(String uid) throws java.rmi.RemoteException,
                                            IllegalArgumentException {
    if (uid == null) {
      throw new IllegalArgumentException("The resume argument must not be null");
    }
    return (Resume)resumeList.get(uid);
  }

  public Resume createDefaultResume() {
    String fName = "Mack";
    String mName = "Levin";
    String lName = "Hendricks";
    String address = "600 Denali";
    String city = "Southfield";
    String state = "MI";
    String zip = "48342";
    String pNumber = "248-555-1212";
    String education = "1998-2000 Oakland University\n" +
                       "Masters of Science in Computer Science\n" +
                       "Rochester Hills, MI 48309\n\n" +
                       "1992-1998 Oakland University\n" +
                       "Bachelor of Science, Computer Science\n" +
                       "Rochester Hills, MI 48309";
    String wHistory = "Work history goes here!";
    String references = "Available upon Request";

    Resume resume = new Resume(fName,mName,lName,address,city,
                               state,zip,pNumber,education,wHistory,references);

    return resume;
  }

  public javax.servlet.ServletConfig getServletConfig() {
    return null;
  }

  public void service(javax.servlet.ServletRequest servletRequest,
                      javax.servlet.ServletResponse servletResponse)
              throws javax.servlet.ServletException, java.io.IOException {
  }
}