// Imports need for JAXM
import javax.xml.soap.SOAPEnvelope;
import javax.xml.soap.SOAPConnectionFactory;
import javax.xml.soap.SOAPConnection;
import javax.xml.soap.SOAPMessage;
import javax.xml.soap.SOAPPart;
import javax.xml.soap.SOAPBody;
import javax.xml.soap.MessageFactory;
import javax.xml.soap.SOAPElement;
import javax.xml.messaging.URLEndpoint;

// Imports needed for processing the output
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.Transformer;
import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamResult;

/*
 * A Standalone JAXM Application that retrieves a resume from the Job Resume
 * Repository Service (JRRS).  
 */

public class JAXMRetrieveResume {
  static final String RPCROUTER = "http://localhost:8080/soap/servlet/rpcrouter";
  public static void main(String args[]) {

    try {
      String uid = null;
      boolean argumentsProcessed = false;

      // Obtain the uid of the resume to retrieve from the command line
      if (args.length == 2) {
        if (args[0].equalsIgnoreCase("-UID") || args[0].equalsIgnoreCase("/UID")) {
          uid =args[1];
          argumentsProcessed = true;
        }
      }
      if (argumentsProcessed == false) {
        System.out.println("Usage: JAXMRetreiveResume [-uid <uid> | /uid <uid>]");
        return;
      }

      SOAPConnectionFactory scf = SOAPConnectionFactory.newInstance();
      SOAPConnection connection = scf.createConnection();

      MessageFactory mf = MessageFactory.newInstance();

      // Create a SOAP message using the message factory.
      SOAPMessage msg = mf.createMessage();

      // Obtain a reference to the SOAP part of the message
      SOAPPart soapPart=msg.getSOAPPart();

      // Obtain a reference to the Envelope 
      SOAPEnvelope envelope = soapPart.getEnvelope();

      // Add namespace declarations so that parameters can be encoded per the XML Schema spec.   
      envelope.addNamespaceDeclaration("xsi", "http://www.w3.org/1999/XMLSchema-instance");
      envelope.addNamespaceDeclaration("xsd", "http://www.w3.org/1999/XMLSchema");

      // Obtain a reference to the Body portion of the SOAP Envelope
      SOAPBody body = envelope.getBody();

      // Specify the RPC method call to invoke
      SOAPElement rpcMethodCall = body.addChildElement("retrieve" , "ns1",
      "urn:JobResumeRepositoryService");

      // Specify the UID parameter as a child element
      SOAPElement rpcParam = rpcMethodCall.addChildElement("uid");

      // Add the data type of the parameter
      rpcParam.addAttribute(envelope.createName("xsi:type"), "xsd:string");

      // Specify the uid of the resume to retrieve
      rpcParam.addTextNode(uid);

      // Creates the endpoint for the message
      URLEndpoint endpoint=new URLEndpoint(RPCROUTER);

      System.out.println("Sending message to URL: "+ endpoint.getURL());

      //Send the message synchronously
      SOAPMessage reply = connection.call(msg, endpoint);

      System.out.println("Received reply from: "+endpoint);

      System.out.println("Resume " + uid + ":");

      // Instantiate an instance of the Transformer object
      TransformerFactory tFact=TransformerFactory.newInstance();
      Transformer transformer = tFact.newTransformer();

      // Obtain a reference to the XML stream received from the remote server 
      Source src=reply.getSOAPPart().getContent();

      // Construct a StreamResult from a character stream
      StreamResult result=new StreamResult( System.out );

      // Transform the XML stream and write it out
      transformer.transform(src, result);
      System.out.println();

      // Close connection to the remote server
      connection.close();
    } catch(Throwable e) {
      e.printStackTrace();
    }
  }
}